@@ -67,7 +67,7 @@ with other DBs.
 
 use v5.16;
 
-package SQL::Steno v0.2.99.0;
+package SQL::Steno v0.3.0;
 
 use strict;
 use warnings;
@@ -208,7 +208,7 @@ our %Macros =
 		[gb147 => $gob], [ob2d5a9 => $gob],
 		['+' => <<INT], ['-' => $int], ['d+2h' => $int], ['y-m' => $int], ['q+0' => $int])
 :B+/-NO this B(ase) +/- N(umber, 0 for none, default 1 if O given) O(ffset)
-	optional B, O is y(ear), q(uarter), m(onth), w(eek), d(ay), h(our), M(inute), s(econd)
+	 optional B, O is y(ear), q(uarter), m(onth), w(eek), d(ay), h(our), M(inute), s(econd)
 INT
 	    unless @_;		# help
 	for( $_[0] ) {
@@ -235,7 +235,7 @@ INT
 		       M => ' date_format(now(),"%F %H:%M")',
 		       s => ' now()' }->{$1} || '') .
 		    ($3 ne '0' &&
-		     "$2interval" .
+		     " $2interval" .
 		     ($3 ? " $3" : $4 ? ' 1' : '') .
 		     ({ y => ' year',
 			q => ' quarter',
@@ -564,39 +564,42 @@ Those starting with C<:gb> (group by) or C<:ob> (order by) may be followed by
 result columns numbers from 1-9, each optionally followed by a or d for asc or
 desc.  E.g. C<:ob2d3> gives C<order by 2 desc, 3>.
 
-Then there are the time macros, where an optional leading letter indicates a
-base time, and an optional trailing letter with an optional count means the
+=head3 C<:+I<interval>> E<nbsp> or E<nbsp> C<:I<time>+I<interval>> E<nbsp> or E<nbsp> C<:-I<interval>> E<nbsp> or E<nbsp> C<:I<time>-I<interval>>
+
+These are time calculation macros, where an optional leading letter indicates
+a base time, and an optional trailing letter with an optional count means the
 offset.  The letters are:
 
 =over
 
 =item y
 
-(this) year.  E.g. C<:y+2m> is march this year.
+(this) year(start).  E.g. C<:y+2m> is march this year.
 
 =item q
 
-(this) quarter.  E.g. C<:q+0> is this quarter, C<:q+q> is next quarter.
+(this) quarter(start).  E.g. C<:q+0> is this quarter, C<:q+q> is next quarter.
 
 =item m
 
-(this) month.  E.g. C<:-3m> is whatever precedes, minus 3 months.
+(this) month(start).  E.g. C<:-3m> is whatever precedes, minus 3 months.
 
 =item w
 
-(this) week (starting on C<$weekstart>).  E.g. C<:w+3d> is this week thursday (or wednesday).
+(this) week(start).  E.g. C<:w+3d> is this week thursday (or wednesday if you
+set C<$weekstart> to not follow ISO 8601 and the bible).
 
 =item d
 
-(this) day.  E.g. C<:d-w> is midnight one week ago.
+(this) day(start).  E.g. C<:d-w> is midnight one week ago.
 
 =item h
 
-(this) hour.  E.g. C<:h+30M> is half past current hour.
+(this) hour(start).  E.g. C<:h+30M> is half past current hour.
 
 =item M
 
-(this) minute.  E.g. C<:+10M> is whatever precedes, plus 10min.
+(this) minute(start).  E.g. C<:+10M> is whatever precedes, plus 10min.
 
 =item s
 
@@ -625,7 +628,8 @@ alias, unless an I<alias> directly follows, in which case that is used.  It trie
 to be clever about whether the 1st C<.> needs to be preserved, i.e. following
 a table name.
 
-=head3 C<I<func>(> E<nbsp> or E<nbsp> C<I<func>\I<spec>(I<strings>)> E<nbsp> or E<nbsp> C<I<func>\I<spec>%I<join>(I<strings>)>
+=head3 C<I<func>(> E<nbsp> or E<nbsp> C<I<func>\I<spec>(I<strings>)> E<nbsp>
+or E<nbsp> C<I<func>\I<spec>%I<join>(I<strings>)>
 
 Here I<func> is a key of C<%Functions> or any
 abbreviation of known functions in C<@Functions>, which includes words
@@ -638,6 +642,8 @@ but in this case preserving the parentheses.
 
 If the 1st argument of a function is empty and the abbrev or function is found
 in C<%DefaultArguments> the value becomes the 1st argument.
+E.g. C<cw(,'a','b','c')> or C<cw(,:\(a,b,c))> both become
+C<concat_ws(',','a','b','c')>.
 
 =head3 Abbreviated Keyword
 
@@ -654,7 +660,7 @@ are frst replaced by C<set> and then C<where>.
 =cut
 
 sub convert {
-    # Handle :\,,,(str1, str2, str3)
+    # Handle :\...(str1, str2, str3)
     s<(?:\b(\w+)|:)$quote_re\((.+?)\)> {
 	($1 ? "$1(" : '') .
  	quote($2, $3, $4 ) .
@@ -971,8 +977,8 @@ order (i.e. C<&I<xyz>> can return C</I<regexp>/=I<literal sql>> etc.):
 =head3 C<&{I<Perl code>} I<following text>>
 
 Run I<Perl code>.  It sees the optional I<following text> in C<$_> and may
-modify it.  If it returns undef this statement is skipped.  If it returns a
-DBI statement handle, run that instead of this statement.  Else replace with
+modify it.  If it returns C<undef>, this statement is skipped.  If it returns
+a DBI statement handle, run that instead of this statement.  Else replace with
 what it returns.
 
 Reprocess result as a shell entry (i.e. it may return another C<&I<query>>).
@@ -993,28 +999,31 @@ arguments a bit like the Shell: C<$0> (I<name>), C<$*> (all arguments), C<$1,
 $2, ..., $10, ...> (individual arguments) and C<$E<gt>> (all arguments not
 adressed individually).  They can become quoted like
 L<C<:\>|/spec-strings-or-:-spec-join-strings> as C<:\I<spec>I<arg>> or
-C<:\I<spec>%I<join>I<arg>>: E.g.: C<$\-"1> splits the 1st (semi-colon
-separated from the 2nd) argument itself on C<-> (minus), quotes the pieces
-with C<"> (double quote) and joins them with C<,> (comma).  Putting the quotes
-inside the argument like this, eliminates them, if no argument is given.
+C<:\I<spec>%I<join>I<arg>>.  Here I<arg> is C<*>, C<E<gt>> or a number
+directly tacked on to I<spec> or I<join>.  E.g.: C<$\-"1> splits the 1st
+(semi-colon separated from the 2nd) argument itself on C<-> (minus), quotes
+the pieces with C<"> (double quote) and joins them with C<,> (comma).  Putting
+the quotes inside the argument like this, eliminates them, if no argument is
+given.
 
 =head3 C</I<regexp>/ I<statement>> E<nbsp> or E<nbsp> C</I<regexp>/i I<statement>> E<nbsp> or E<nbsp> C<!/I<regexp>/ I<statement>> E<nbsp> or E<nbsp> C<!/I<regexp>/i I<statement>>
 
 This will treat the I<statement> normally, but will join each output row into
-a C<~> (tilde) separated string for matching.  NULL fields are rendered as that
-string.
+a C<~> (tilde) separated string for matching.  NULL fields are rendered as
+that string.  E.g. to return only rows starting with a number 1-5, followed by
+a NULL field, you could write: C</^[1-5]~NULL~/>.
 
 With a suffix C<i>, matching becomes case insensitive.  This is why the mostly
-optional space is shown above.  Without an C<i>, but if the statement starts
-with the word C<i> (e.g. your first column name), you must separate it with a
-space.  With an C<i>, if the statement starts with an alphanumeric caracter,
-you must separate it with a space.
+optional space before I<statement> is shown above.  Without an C<i>, but if
+the statement starts with the word C<i> (e.g. your first column name), you
+must separate it with a space.  With an C<i>, if the statement starts with an
+alphanumeric caracter, you must separate it with a space.
 
-Only matching rows are considered unless there is a preceding C<!>, in which
-case only non-matching rows are considered.
+Only matching rows are considered unless there is a preceding C<!>
+(exclamation mark), in which case only non-matching rows are considered.
 
 You can provide your own formatting of the row by setting C<$regexp_fail> to a
-perl sub that returns a Perl expression as a string.  That expression takes
+Perl sub that returns a Perl expression as a string.  That expression takes
 the row in C<@_> and shall be true if the row fails to match.
 
 Caveat: the whole result set of the I<statement> gets generated and
@@ -1030,7 +1039,7 @@ array of column names as zeroth argument and the values after that (i.e.
 numbered from 1 like in SQL).  It may modify individual values.  If it returns
 false, the row is skipped.
 
-You may combine S<C</regexp/{Perl code}>> in any order and as many of them as
+You may combine S<C</I<regexp>/{I<Perl code>}>> in any order and as many of them as
 you want.
 
 The same caveat as for regexps applies here.  But again Perl is far more
@@ -1045,8 +1054,8 @@ or where the conversion doesn't play well with your intention.
 
 Help prefix.  Alone it will give an overview.  You can follow up with any of
 the special syntaxes, with or without an abbreviation.  E.g. C<?(> will show
-all function abbreviations, whereas C<?abbrev(> will show only those functions
-matching abbrev or C<?#abbrev> only those tables matching abbrev.
+all function abbreviations, whereas C<?I<abbrev>(> will show only those functions
+matching abbrev or C<?#I<abbrev>> only those tables matching abbrev.
 
 =head3 C<??I<statement>>
 
@@ -1055,7 +1064,7 @@ is the default behaviour.
 
 =head3 C<!I<System Shell code>>
 
-Run it.
+Run I<System Shell code>.
 
 =head3 C<E<gt>I<filename>> E<nbsp> or E<nbsp> C<E<gt>E<gt>I<filename>>
 
@@ -1074,17 +1083,17 @@ comma-separated options may be passed:
 
 =over
 
-=item >filename.suffix
+=item >I<filename>.I<suffix>
 
-=item >filename.suffix( opt; ... )
+=item >I<filename>.I<suffix>( I<opt>; ... )
 
-=item >>filename.suffix
+=item >>I<filename>.I<suffix>
 
-=item >>filename.suffix( opt; ... )
+=item >>I<filename>.I<suffix>( I<opt>; ... )
 
-=item &.suffix opt; ...
+=item &.I<suffix opt>; ...
 
-=item &.suffix( opt; ... ) following text
+=item &.I<suffix>( I<opt>; ... ) following text
 
 =back
 
@@ -1104,7 +1113,7 @@ can take one of these options:
 =item semi
 
 Use a semicolon as a separator.  This is a common format in environments where
-the comma is the decimal separator.  However if you want commas, you must
+the comma is the decimal separator.  However if you want decimal commas, you must
 provide such formatting yourself.
 
 =item tab
@@ -1145,8 +1154,8 @@ hh: or hh:mm(:00) to hh:mm.
 
 =item null
 
-Output this keyword instead of the shorter C<ω> (or whatever you assigned to
-C<$NULL>).
+Output this keyword instead of the shorter C<ω> from DB theory (or whatever
+you assigned to C<$NULL>).
 
 =back
 
@@ -1330,7 +1339,7 @@ sub help {
 All entries are single line unless \\wrapped at 1st bol and last eol\\ or continued.\
 Queries have the form: {{!}/regexp/{i}}{=}query
 The query has lots of short-hands expanded, unless it is prefixed by the optional =.
-The fields joined with '|' are grepped if regexp is given, case-insensitively if i is given.
+The fields joined with '~' are grepped if regexp is given, case-insensitively if i is given.
 
 ??query		Only shows massaged query.
 !perl-code	Runs perl-code.
@@ -1339,14 +1348,14 @@ The fields joined with '|' are grepped if regexp is given, case-insensitively if
 Query has the form {select|update|insert|delete}{fieldlist};tablelist{;clause} or set ...
 'select' is prepended if none of these initial keywords.
 fieldlist defaults to '*', also if Query starts with '#'.
-';' is alternately replaced by 'from' and 'where' except '\;'.
+';' is alternately replaced by 'from' and 'where'.
 
-Abbreviations, more help with ?&{abbrev}, ?#{abbrev}, ?.{abbrev}, ?{abbrev}(, ?:{abbrev}
+Abbreviations, more help with ?&{abbrev}, ?:{abbrev}, ?#{abbrev}, ?.{abbrev}, ?{abbrev}(
+&{Perl code}...		# only at bol, if it returns undef then skip, else prepend to ...
 &query $1;$2;...	# only at bol
 &query($1;$2;...)...	# only at bol, only replace upto )
-&{Perl code}...		# only at bol, if it return undef then skip, else prepend to ...
-#table
-.column			# for any table recognized in statement
+#table #table#t
+.column	.column.c	# for any table recognized in statement
 function(
 :macro
 :{Perl code}		# dynamic macro
@@ -1365,13 +1374,16 @@ HELP
 	print <<\HELP unless $_[1];
 &{ Query name => 'doc', 'query' }   define query &name on the fly
 	query may contain arguments a bit like the Shell: $1, $2, ..., $*
-	they can become quoted: $'1', $"2", $`*`, $[3], ${4}
-	$* means the remaining args after using up the numbered ones
+	they can become quoted: $\1, $\"2, $\`*, $\[3, $\{}>
+	$* means all args; $> the remaining args after using up the numbered ones
 	if it is quoted, each arg gets quoted, separated by a comma
-	$?args-replacement?no-args-replacement? 1st if remaining args
+	$?arg?arg-replacement?no-arg-replacement? 1st if $arg has a value
 HELP
 	helphash $_[1], '&', '', %Queries_help;
     } else {
+	print <<\HELP unless $_[1];
+:\(...)	 split arguments and quote in many ways
+HELP
 	local $Tables{TBL} = 'TABLE';
 	helphash $_[1], ':', '', %Macros;
     }
